module.exports = defineTest({
	description: 'supports exporting and resolving internal namespaces as names'
});
